@@ -92,9 +92,11 @@ class ParameterSweep(object):
             return "Variables"
 
     def _generateImitate(self, classvalue, value):
-        if type(classvalue) == np.ndarray:
+        if type(classvalue) == np.ndarray and len(classvalue) > 1:
             v = deepcopy(classvalue)
             v = np.where(self.ParametersLEDET.Inputs.polarities_inGroup != 0, value, v)
+        elif type(classvalue) == np.ndarray:
+            v = np.array([value])
         else:
             v = value
         return v
@@ -177,11 +179,12 @@ class ParameterSweep(object):
             if Adjust_vQ:
                 self.ParametersLEDET.adjust_vQ(ROXIE_File)
 
-            self.ParametersLEDET.Variables.variableToSaveTxt = np.append(self.ParametersLEDET.Variables.variableToSaveTxt, 'I_CoilSections')
-            self.ParametersLEDET.Variables.typeVariableToSaveTxt = np.append(self.ParametersLEDET.Variables.typeVariableToSaveTxt, 1)
             self.ParametersLEDET.Options.flag_saveMatFile = 0
             self.ParametersLEDET.Options.flag_generateReport = 0
             self.ParametersLEDET.writeFileLEDET(file_name)
+        if 'I_CoilSections' not in self.ParametersLEDET.Variables.variableToSaveTxt:
+            self.ParametersLEDET.Variables.variableToSaveTxt = np.append(self.ParametersLEDET.Variables.variableToSaveTxt, 'I_CoilSections')
+            self.ParametersLEDET.Variables.typeVariableToSaveTxt = np.append(self.ParametersLEDET.Variables.typeVariableToSaveTxt, 1)
 
         #4. Write CSV with all Parameters
         SimNumbers = np.linspace(0,self.SweepMatrix.shape[0]-1,self.SweepMatrix.shape[0])
