@@ -1,6 +1,7 @@
 from steam_nb_api.ledet.ParameterSweep import *
 from steam_nb_api.ledet.ParametersLEDET import ParametersLEDET
 from steam_nb_api.ledet.ParametersLEDET import *
+from steam_nb_api.ledet.NotebookLEDET_V2 import *
 import pandas as pd
 from steam_nb_api.ledet.Simulation import RunSimulations
 from steam_nb_api.ledet.SimulationEvaluation import EvaluateSimulations
@@ -8,6 +9,8 @@ from steam_nb_api.ledet.QuenchAnalysis import QuenchPlanAnalysis
 from steam_nb_api.ledet.AutomaticSweep import AutomaticSweep
 import time
 
+from steam_nb_api.utils.MP3_simulations import *
+
 testfile1 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MBRC\MBRC_0.xlsx"
 testfile2 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MBRB\MBRB_0.xlsx"
 testfile3 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MBRS\MBRS_0.xlsx"
@@ -21,8 +24,9 @@ testfile10 = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MCBXV\M
 testfile11 = "C:\cernbox\TEMP2\MCBY_1AP_CopperWedges_ThCool_29.xlsx"
 testfile12 = "C:\cernbox\LEDET\LEDET\MCBY_1AP_CopperWedges_ThCool\Input\MCBY_1AP_CopperWedges_ThCool_35.xlsx"
 testfile13 = "C:\cernbox\LEDET_MT\LEDET\MQXFS4b\Input\MQXFS4b_23.xlsx"
+testfile14 = "C:\cernbox\MasterThesis\MQY studies\MQY_2in1_Ref.xlsx"
 
-ledetFolder = 'C:\\cernbox\\LEDET_MT\\'
+ledetFolder = 'C:\\cernbox\\LEDET_OS\\'
 ledetExe = 'LEDET_v1_08_03.exe'
 
 def CompleteRun():
@@ -32,10 +36,10 @@ def CompleteRun():
     Sw = MinMaxSweep(a, 6)
     MagnetName = 'MQXFS4b'
 
-    ##MQXF
-    Sw.addParameterToSweep('tau_increaseRis', 0.001, 0.1)
-    Sw.addParameterToSweep('f_ro_eff_inGroup', 0.75, 3)
-    Sw.addParameterToSweep('tau_increaseRif', 0.001, 0.1)
+    # ##MQXF, 6 base points
+    Sw.addParameterToSweep('tau_increaseRis', 0.001, 0.2)
+    Sw.addParameterToSweep('Rcapa', 0.00001, 0.1)
+    Sw.addParameterToSweep('tau_increaseRif', 0.001, 0.2)
 
 
     ##13mag
@@ -83,14 +87,15 @@ def CompleteRun():
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\LEDET\\LEDET\\MCBXV_CopperWedges_ThCool\\Input\\")
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\\TEMP2\\", OffsetNumber= 42, ROXIE_File='C:\\cernbox\\SWAN_projects\\steam-notebooks\\steam-ledet-input\\MCBXV\\MCBXV_CopperWedges_All_WithIron_WithSelfField.map2d')
     # Sw.prepareSimulation(MagnetName, "C:\\cernbox\\TEMP2\\", OffsetNumber=17, ROXIE_File='C:\\cernbox\\SWAN_projects\\steam-notebooks\\steam-ledet-input\\MCBY_1AP\\MCBY_1AP_CopperWedges_ThCool_All_WithIron_WithSelfField.map2d')
-    # Sw.prepareSimulation(MagnetName, "C:\\cernbox\\TEMP2\\", OffsetNumber=50)
+    # Sw.prepareSimulation(MagnetName, "C:\\cernbox\\TEMP\\", OffsetNumber=50)
+    # Sw.prepareSimulation(MagnetName, "C:\\cernbox\\TEMP\\")
 
 
     end = time.time()
     print("Time:", end - start)
     print("Preparation done")
 
-    # SimNumbers = np.linspace(100,315, 216).astype(int)
+    # SimNumbers = np.linspace(50,265, 216).astype(int)
 
     # RunSimulations(ledetFolder, ledetExe, MagnetName, Simulations = SimNumbers, RunSimulations=False)
     # EvaluateSimulations("C:\\cernbox\\LEDET\\LEDET\\MCO\\Output\\Txt Files", 'MCO',
@@ -123,12 +128,11 @@ def CompleteRun():
     #                     'MCBXH_CopperWedges_ThCool',
     #                     'C:\\cernbox\\Validation_MCBX_HV\\Exp Data\\RCBXH1.R1_2018-03-11_PM_I_ARAW.csv',
     #                     Sw, Mat=False)
-    EvaluateSimulations("C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Txt Files",
+    EvaluateSimulations("C:\\cernbox\\LEDET_OS\\LEDET\\MQXFS4b\\Output\\Txt Files",
                         MagnetName,
                         'C:\\cernbox\\MasterThesis\\Test23_ParSweepMeas.csv',
                         Sw, Mat=False)
 
-
 def AutomaticRun():
     LEDETFolder = 'C:\\cernbox\LEDET\\LEDET_SimulationFiles_Quench'
     LEDETExe = 'LEDET_v1_07_01_6February2020.exe'
@@ -148,7 +152,7 @@ def AutomaticRun():
 def testConsistencyChecks():
     a = ParametersLEDET()
     a.readLEDETExcel(testfile10)
-    x = a.consistencyCheckLEDET()
+    x = a._consistencyCheckLEDET()
     print(x)
 
 def testvQ():
@@ -226,24 +230,252 @@ def testQuenchPlanAnalysis(FileName_TDMS, FileName_Sim, verbose = True):
     a = QuenchPlanAnalysis(FileName_TDMS, FileName_Sim, verbose = verbose)
     # a = QuenchPlanAnalysis(0, FileName_Sim)
     # a.ProvideTurnsToCoilStructure(Coil = [Coil109,Coil110,Coil111,Coil108])
-    a.ProvideTurnsToCoilStructure(CoilCsv = 'C:\cernbox\MasterThesis\CoilStructure_MQXFPB2.csv')
+    # a.ProvideTurnsToCoilStructure(CoilCsv = 'C:\cernbox\MasterThesis\CoilStructure_MQXFPB2.csv')
+    a.ProvideTurnsToCoilStructure(CoilCsv='C:\cernbox\MasterThesis\CoilStructure_MQXFS4b.csv')
     # a.QuenchPlanAnalysis(Plot = 1)
-    # a.FindQuenchTDMS(0.1, 0.007, Plot=0)
-    a.PlotVoltageTap(Coil = 1)
+    # a.FindQuenchTDMS(0.1, 0.007, Plot=1)
+    # a.PlotVoltageTap(Coil = 110)
     # a.PlotVoltageTap(TapName = 'C109_I2_I3')
+    # a.calculateAllQuenchIntegrals()
     # a.calculateAllQuenchIntegrals(TDMS = 0)
     # a.calculateAllQuenchIntegrals(SIM = 0)
     return a
 
 def PrepareSimulations():
-    PlanFile = "C:\cernbox\MasterThesis\MQFBP2 Test\MQXFBP2_QuenchPlan_Masterfile.xlsx"
-    RefFile = "C:\cernbox\MasterThesis\MQFBP2 Test\MQXFBP2_Ref_0.xlsx"
+    # PlanFile = "C:\cernbox\MasterThesis\MQFBP2 Test\MQXFBP2_QuenchPlan_Masterfile.xlsx"
+    # RefFile = "C:\cernbox\MasterThesis\MQFBP2 Test\MQXFBP2_Ref_0.xlsx"
+    PlanFile = "C:\cernbox\MasterThesis\MQY studies\QuenchPlan_MQY.xlsx"
+    RefFile = "C:\cernbox\MasterThesis\MQY studies\MQY_2in1_Ref.xlsx"
     OutputDirectory = "C:\cernbox\TEMP"
 
     a = QuenchPlanAnalysis(0, 0)
     a.PrepareSimulations(PlanFile, RefFile, OutputDirectory,
-                         QHpairs=[[1,5],[2,6],[3,7],[4,8],[9,13],[10,14],[11,15],[12,16]])
+                         QHpairs=[], nQHseries = 4)
 
+def testLEDETnotebook():
+    new_notebook = Notebook_LEDET('MBRB')
+
+
+    T00 = 4.5
+    l_magnet = 9.45
+    I00 = 5800  # Current to be simulated
+    new_notebook.setAttribute('GroupToCoilSection', new_notebook.nGroups * [1])
+    new_notebook.setAttribute('I00', I00)
+
+    new_notebook.load_ConductorData(['Type2','Type2'],[1,2]*int(new_notebook.nGroups/2))
+    elPairs_GroupTogether = [[1, 17], [2, 18], [3, 19], [4, 20], [5, 21], [6, 22], [7, 23], [8, 24], [9, 25], [10, 26],
+                             [11, 27], [12, 28], [13, 29], [14, 30], [15, 31], [16, 32]]
+    elPairs_RevElOrder = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
+    new_notebook.set_ElectricalOrder(elPairs_GroupTogether, elPairs_RevElOrder)
+
+    max_distance = 0.5E-3
+    new_notebook.set_ThermalConnections(max_distance)
+
+    new_notebook.load_Options('Default')
+
+    # Resistance of the warm parts of the circuit [Ohm]
+    R_circuit = 7.76E-4
+    # Resistance of crowbar of the power supply [Ohm]
+    R_crowbar = 5.6E-5
+    # Forward voltage drop of a diode or thyristor in the crowbar of the power supply [V]
+    Ud_crowbar = 0.34
+
+    t_PC = 0
+    tStart = -0.02
+    Transient = 'FPA'
+
+
+    # R_EE_triggered = 0.066
+    # tEE = 99999
+
+    # # Time when the CLIQ system is triggered [s]
+    # tCLIQ = 99999
+    # # Direction of the introduced current change for the chosen CLIQ configuration
+    # directionCurrentCLIQ = [1]
+    # # Number of CLIQ units
+    # nCLIQ = 1
+    # # CLIQ charging voltage [V]
+    # U0 = 1000
+    # # Capacitance of the CLIQ capacitor bank [F]
+    # C = 0.04
+    # # Resistance of the CLIQ leads [Ohm]
+    # Rcapa = 0.05
+
+    # Number of quench heater strips to write in the file
+    nHeaterStrips = 8
+    # Number of QH circuits
+    nQHcircuits = 2
+    # Time at which the power supply connected to the QH strip is triggered (Low-field QHs set to a very large value to avoid triggering).
+    tQH = nHeaterStrips * [.002]
+    # Charging voltage of the capacitor connected to the QH strip.
+    U0_QH = nHeaterStrips * [900 / nQHcircuits]
+    # Capacitance of the capacitor connected to the QH strip.
+    C_QH = nHeaterStrips * [7.05E-3 * nQHcircuits]
+    # Resistance of the warm leads of the QH strip discharge circuit.
+    R_warm_QH = nHeaterStrips * [
+        0.2 * nQHcircuits]  # 0.25-->0.28 Ohm partially compensates the fact that the real strip is 9.646 m long instead of l_magnet=9.450 m long
+    # Width of the non-Cu-plated part of the the QH strip.
+    w_QH = nHeaterStrips * [15E-3]
+    # Height of the non-Cu-plated part of the QH strip.
+    h_QH = nHeaterStrips * [0.025E-3]
+    # Thickness of the insulation layer between QH strip and coil insulation layer.
+    s_ins_QH = nHeaterStrips * [75E-6]
+    # Type of materialof the insulation layer between QH strip and coil insulation layer (1=G10; 2=kapton)
+    type_ins_QH = nHeaterStrips * [2]
+    # Thickness of the insulation layer between QH strip and the helium bath (or the collars); on this side, the QH strip is thermally connected to an infinite thermal sink at constant temperature.
+    s_ins_QH_He = nHeaterStrips * [500E-6]
+    # Type of material of the insulation layer between QH strip and helium bath (1=G10; 2=kapton)
+    type_ins_QH_He = nHeaterStrips * [2]
+    # Length of the QH strip.
+    l_QH = nHeaterStrips * [l_magnet]
+    # Fraction of QH strip covered by heating stations (not-Cu-plated).
+    f_QH = nHeaterStrips * [.127 / (.127 + .633)]
+
+    # Heat exchange between quench heater strips and half-turns
+    iQH_toHalfTurn_From_oneHalfQuadrant = [1, 1, 1, 1, 1, 1, 1, 1]
+    iQH_toHalfTurn_To_oneHalfQuadrant = [1, 2, 3, 4, 5, 6, 7, 8]
+
+    nHalfTurnsDefined = new_notebook.nHalfTurns
+    nHalfQuadrants = 8
+    # Inclination of cables with respect to X axis (including transformations for mirror and rotation)
+    alphasDEG = nHalfQuadrants * [0, 1.2404, 2.4808, 3.7212, 4.9616, 6.202, 7.4424, 8.6828, 9.9232, 0, 1.2404, 2.4808,
+                                  3.7212, 4.9616, 6.202, 7.4424, 8.6828, 9.9232, 11.1636, 12.404, 0, 1.2404, 2.4808,
+                                  3.7212, 4.9616, 6.202, 7.4424, 8.6828, 0, 1.2404, 2.4808, 3.7212]
+    # Rotate cable by a certain angle [deg]
+    rotation_block = int(nHalfTurnsDefined / 8) * [0] + int(nHalfTurnsDefined / 8) * [180] + int(
+        nHalfTurnsDefined / 8) * [0] + int(nHalfTurnsDefined / 8) * [180] + int(nHalfTurnsDefined / 8) * [90] + int(
+        nHalfTurnsDefined / 8) * [270] + int(nHalfTurnsDefined / 8) * [90] + int(nHalfTurnsDefined / 8) * [270]
+    # Mirror cable along the bisector of its quadrant (0=no, 1=yes)
+    mirror_block = int(nHalfTurnsDefined / 2) * [0] + int(nHalfTurnsDefined / 2) * [1]
+    # Mirror cable along the Y axis (0=no, 1=yes)
+    mirrorY_block = nHalfTurnsDefined * [0]
+
+    # Copy/paste the values after calculation using ROXIE or COMSOL or another software
+    fL_I = [0, 60.5, 511.225, 961.95, 1412.675, 1863.4, 2314.125, 2764.85, 3215.575, 3666.3, 4117.025, 4567.75,
+            5018.475, 5469.2, 5919.925, 6370.65, 6821.375, 7272.1, 7722.825, 8173.55, 8624.275, 9075]
+    fL_L = [1.50847185630795, 1.50847185630795, 1.50847185630795, 1.50846737882912, 1.50841522306793, 1.50830395909222,
+            1.50822527083526, 1.50806904802754, 1.50787422001269, 1.50745689700945, 1.50645441147256, 1.50388608565927,
+            1.49507688502376, 1.47034904670854, 1.4380027616657, 1.40295544163306, 1.35977890716088, 1.30439619675877,
+            1.23307412316907, 1.17633437683201, 1.14099904228627, 1.11820344760328]
+
+    # Time Vector Definition. Parameters used to generate the time vector.
+    # Each triplet of numbers defines a time window: first element is the start time, second element is the time step in that window, third element is the end time. It must contain a number of elements multiple of 3. Any time point above t=1000 s will be ignored.
+    time_vector_params = [tStart, 5E-4, 0, 5E-4, 5E-4, 0.5, 0.501, 0.001, 1]
+
+    # Time from which the adiabatic hot-spot temperature calculation starts. For each coil section, calculate the adiabatic hot-spot temperature in the highest-field strand/cable [s]
+    tQuench = tStart
+    # Initial quench temperature in the hot-spot temperature calculation [K]
+    initialQuenchTemp = 10
+
+    # Further stuff
+    new_notebook.set_SimulationType('2D+1D')
+    new_notebook.load_VariablesToStore('Default')
+    new_notebook.load_PlotOptions('Default')
+    new_notebook.storeVariables(locals())
+
+    new_notebook.initiateQuench([1,5,10],[0.1,0.2,3], lengthHotspot=[2,3,4])
+    new_notebook.setHeliumFraction(2)
+    new_notebook.includeBusbar(5000)
+
+    # Finish up
+    nameMagnet = 'MBRB'
+    nameFileLEDET = nameMagnet + '_TEST_0' + '.xlsx'
+    new_notebook.writeLEDETFile(nameFileLEDET, locals())
+
+    new_notebook.plot_all()
+
+    return new_notebook
+
+def test_persCurrents():
+    a = ParametersLEDET()
+    a.readLEDETExcel( "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MO_1AP\MO_1AP_8magBB_0.xlsx")
+    a.Inputs.fitParameters_inGroup = np.ones((3, 16))
+    a.Inputs.df_inGroup = np.ones((16,)).transpose()
+    a.Inputs.selectedFit_inGroup = np.ones((16,)).transpose()
+    # a.Options.flag_persistentCurrents = 1
+    a.writeFileLEDET('A.xlsx')
+    return a
+
+def testOldLEDETnotebook():
+    from steam_nb_api.ledet.NotebookLEDET import NB_LEDET as nl
+    nameMagnet = "MainSolenoid"  # coil name in imput folder
+    model_n = 0  # this is model number and gets added as _model_n in LEDET input file name
+    n = nl(nameMagnet, model_n)  # create notebook object called n
+    n.write_ledet_input()
+    return n
+
+def testSolenoids():
+    new_notebook = Notebook_LEDET('MainSolenoid_New', typeMagnet = 'solenoid')
+
+    nGroups = new_notebook.nGroups
+    new_notebook.load_ConductorData(['W1'], [1] * int(new_notebook.nGroups))
+
+    elPairs_GroupTogether = []
+    for i in range(0,nGroups,2):
+        elPairs_GroupTogether.append([nGroups-i, nGroups-i-1])
+    elPairs_RevElOrder = [0, 1, 0]
+    new_notebook.set_ElectricalOrder(elPairs_GroupTogether, elPairs_RevElOrder)
+
+    max_distance = 0.5E-3
+    new_notebook.set_ThermalConnections(max_distance)
+
+    R_circuit = 7.76E-4
+    R_crowbar = 5.6E-5
+    Ud_crowbar = 0.34
+
+    t_PC = 0
+    tStart = -0.02
+    Transient = 'FPA'
+
+    nHalfTurnsDefined = new_notebook.nHalfTurns
+    alphasDEG = nHalfTurnsDefined * [0]
+    rotation_block = nHalfTurnsDefined * [0]
+    mirror_block = nHalfTurnsDefined * [0]
+    mirrorY_block = nHalfTurnsDefined * [0]
+
+    fL_I = [0, 1000]
+    fL_L = [1, 1]
+
+    time_vector_params = [tStart, 5E-4, 0, 5E-4, 5E-4, 0.5, 0.501, 0.001, 1]
+    tQuench = tStart
+    initialQuenchTemp = 10
+
+    # Further stuff
+    new_notebook.load_Options('Default')
+    new_notebook.set_SimulationType('2D')
+    new_notebook.load_VariablesToStore('Default')
+    new_notebook.load_PlotOptions('Default')
+    new_notebook.storeVariables(locals())
+
+
+    # Finish up
+    nameMagnet = 'MainSolenoid_New'
+    nameFileLEDET = nameMagnet + '_TEST_0' + '.xlsx'
+    new_notebook.writeLEDETFile(nameFileLEDET, locals())
+
+    # new_notebook.plot_all()
+
+    return new_notebook
+
+def testMP3():
+    ParameterFile = "600A_Circuit_Param_Table.csv"
+    MP3 = MP3_setup('600A', 'RSS.A78B1', ParameterFile)
+    MP3.load_config('MarvinJ')
+    MP3.SetUpSimulation('FPA', 250)
+
+    return MP3
+
+# a = test_persCurrents()
+
+# nb = testOldLEDETnotebook()
+
+# nb = testSolenoids()
+
+nb = testMP3()
+
+# nb= testLEDETnotebook()
+
+# CompareLEDETParameters("C:\cernbox\steam-notebook-api\steam_nb_api\ledet\MBRB_TEST_0.xlsx","C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\MBRB\MBRB_0.xlsx")
 
 # testConsistencyChecks()
 
@@ -259,20 +491,13 @@ def PrepareSimulations():
 
 # CompareLEDETParameters("C:\cernbox\MB_92.xlsx", "C:\cernbox\MB_98.xlsx")
 
-
-# test_readLEDETExcel()
-# test_setgetAttributes()
-# test_permutations()
-# test_SetUpSimulations()
-# test_EvaluateSimulations()
-
 # CompleteRun()
 
 # PrepareSimulations()
 
 # a  = testvQ()
 
-td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFPB01\\HCLMQXFBT01-CR000001__A202007140955_a001(0).tdms"
+# td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFPB01\\HCLMQXFBT01-CR000001__A202007140955_a001(0).tdms"
 
 # td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810151854_a026(0).tdms"
 # td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810111418_a003(0).tdms"
@@ -289,7 +514,7 @@ td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFPB01\\HCLMQXFBT01-CR
 # td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810161600_a033(0).tdms"
 
 # sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFBP2\\Output\\Mat Files\\SimulationResults_LEDET_10.mat"
-sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_12.mat"
+# sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_12.mat"
 # sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_10.mat"
 # sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_27.mat"
 # sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_15.mat"
@@ -299,7 +524,7 @@ sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\Simulation
 # sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_12.mat"
 # sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_26.mat"
 
-a = testQuenchPlanAnalysis(td_data, sim_data)
+# a = testQuenchPlanAnalysis(td_data, sim_data)
 # a.ExtractFeatures()
 # a = testQuenchPlanAnalysis(0, sim_data)
 # a = testQuenchPlanAnalysis(td_data, 0)
@@ -319,3 +544,7 @@ a = testQuenchPlanAnalysis(td_data, sim_data)
 # Sw.prepareSimulation(MagnetName, "C:\\cernbox\\TEST-DELTE\\")
 
 # x = AutomaticRun()
+
+# a = ParametersLEDET()
+# a.readLEDETExcel(testfile13)
+# a.writeFileLEDET('Test_todelete.xlsx')
\ No newline at end of file
