@@ -34,15 +34,15 @@ class ParametersCOSIM:
         self.circuitName = nameCircuit
         if type(nameMagnet) != list: self.nameMagnet = [nameMagnet]
         else: self.nameMagnet = nameMagnet
-        self.executionOrder = []
-        self.SimulationNumber = []
+        self.executionOrder = [0]
+        self.SimulationNumber = [0]
 
         # Load and set the default config files (using ResourceReader allows reading from a "hidden" resource folder)
         self.nameTemplateConfigFileCosim = ResourceReader.getResourcePath(os.path.join('sing', 'STEAMConfig.json'))
         self.nameTemplateConfigFilePSpice = ResourceReader.getResourcePath(os.path.join('sing', 'PSpiceConfig.json'))
         self.nameTemplateConfigFileLedet = ResourceReader.getResourcePath(os.path.join('sing', 'LedetConfig.json'))
 
-    def makeAllFolders(self, N_LEDET = 1):
+    def makeAllFolders(self, N_LEDET = 1, LEDET_only = 0):
         '''
             **Makes a COSIM folder with the required PSPICE and LEDET subfolders**
 
@@ -57,10 +57,11 @@ class ParametersCOSIM:
         if not os.path.exists(nameFolderCosimModel):
             os.makedirs(nameFolderCosimModel)
 
-        # Make SPICE model folder
-        pathFolderPSpice = os.path.join(nameFolderCosimModel, 'PSpice')
-        if not os.path.exists(pathFolderPSpice):
-            os.makedirs(pathFolderPSpice)
+        if not LEDET_only:
+            # Make SPICE model folder
+            pathFolderPSpice = os.path.join(nameFolderCosimModel, 'PSpice')
+            if not os.path.exists(pathFolderPSpice):
+                os.makedirs(pathFolderPSpice)
 
         # Make LEDET model folder and sub-folders
         if N_LEDET == 1:
@@ -497,26 +498,27 @@ class ParametersCOSIM:
                     fN.write(ls)
             fN.close()
 
-    def copyCOSIMfiles(self, nameFileSING, StimulusFile, nameMagnet, N_LEDET=1, ManuallyStimulusFile = ''):
+    def copyCOSIMfiles(self, nameFileSING, StimulusFile, nameMagnet, N_LEDET=1, LEDET_only = 0, ManuallyStimulusFile = ''):
         LEDETFiles = os.path.abspath(os.path.join(os.path.abspath(os.path.join(os.getcwd(), os.pardir)),os.pardir))
         LEDETFiles = os.path.join(LEDETFiles, "steam-ledet-input")
         nameFolderCosimModel = self.nameFolderCosimModel
 
         if type(nameMagnet) != list: nameMagnet = [nameMagnet]
 
-        # Copy PSPICE model file
-        if len(ManuallyStimulusFile) == 0:
-            StimulusFile = self.FindLibPath(StimulusFile)
-            if StimulusFile == False: return
-        else:
-            StimulusFile = ManuallyStimulusFile
-        nameFolderPSpiceModel = os.path.join(nameFolderCosimModel, 'PSpice')
-        if not os.path.isdir(nameFolderPSpiceModel):
-            os.mkdir(nameFolderPSpiceModel)
+        if not LEDET_only:
+            # Copy PSPICE model file
+            if len(ManuallyStimulusFile) == 0:
+                StimulusFile = self.FindLibPath(StimulusFile)
+                if StimulusFile == False: return
+            else:
+                StimulusFile = ManuallyStimulusFile
+            nameFolderPSpiceModel = os.path.join(nameFolderCosimModel, 'PSpice')
+            if not os.path.isdir(nameFolderPSpiceModel):
+                os.mkdir(nameFolderPSpiceModel)
 
-        self.CopyCircuit(nameFileSING, os.path.join(nameFolderPSpiceModel, 'Circuit.cir'))
-        # makeCopyFile(nameFileSING, os.path.join(nameFolderPSpiceModel, 'Circuit.cir'))
-        makeCopyFile(StimulusFile, os.path.join(nameFolderPSpiceModel, 'ExternalStimulus.stl'))
+            self.CopyCircuit(nameFileSING, os.path.join(nameFolderPSpiceModel, 'Circuit.cir'))
+            # makeCopyFile(nameFileSING, os.path.join(nameFolderPSpiceModel, 'Circuit.cir'))
+            makeCopyFile(StimulusFile, os.path.join(nameFolderPSpiceModel, 'ExternalStimulus.stl'))
 
         LEDET_Fs = []
         for i in range(N_LEDET):
@@ -545,7 +547,7 @@ class ParametersCOSIM:
                 if file.endswith(str(nM)+"_"+str(SimNumber) +'.xlsx') and not file.startswith(".sys"):
                     shutil.copy(os.path.join(sourcedir, file), os.path.join(destinationpath_para, file))
                     LEDET_Fs.append(os.path.join(destinationpath_para, file))
-                if file.endswith('_selfMutualInductanceMatrix.csv'):
+                if file.endswith('_selfMutualInductanceMatrix.csv') and not file.startswith(".sys"):
                     shutil.copy(os.path.join(sourcedir, file), os.path.join(destinationpath_para, file))
         return LEDET_Fs
 
@@ -570,9 +572,13 @@ class ParametersCOSIM:
             for i in range(len(files)):
                 file = files[i]
                 [Tnew, Snew] = self.prepareSingleLEDETFile(file)
-                if self.executionOrder[i+1] == num:
-                    TurnNumber = TurnNumber + Tnew
-                    steps = steps + Snew
+                try:
+                    if self.executionOrder[i+1] == num:
+                        TurnNumber = TurnNumber + Tnew
+                        steps = steps + Snew
+                except:
+                    TurnNumber = Tnew
+                    steps = Snew
             TurnNumber = int(TurnNumber / len(files))
             steps = int(steps / len(files))
         else:
@@ -604,16 +610,38 @@ class ParametersCOSIM:
 
         return [TurnNumber, steps]
 
-    def writeCOSIMBatch(self, COSIMfolder, COSIMexe, Destination = ''):
+    def __findOccurrences(self, s, ch):
+        return [i for i, letter in enumerate(s) if letter == ch]
+
+    def writeCOSIMBatch(self, COSIMfolder, COSIMexe, Destination = '', LEDET_exe = ''):
         if type(COSIMfolder) != list:
             COSIMfolder = [COSIMfolder]
-        if Destination: fileName = Destination+'COSIM_nb_Batch.bat'
+        stub = ''
+        if LEDET_exe:
+            LEDET_exe = LEDET_exe.replace('\ ', '\\')
+            idx = self.__findOccurrences(LEDET_exe, '\\')[-1]
+            stub = LEDET_exe[:idx]+'\\'
+        if Destination: fileName = Destination+'\\COSIM_nb_Batch.bat'
         else: fileName = 'COSIM_nb_Batch.bat'
         fN = open(fileName, 'w+')
 
         txt_stub = "java -jar " + COSIMexe
         for i in range(len(COSIMfolder)):
-            tx_line = txt_stub + " " + str(COSIMfolder[i]) + "\\STEAMConfig.json" + " \n "
-            fN.write(tx_line)
+            if '_L_' in str(COSIMfolder[i]):
+                if not stub:
+                    print('Please provide LEDET_executable. Abort.')
+                    return
+                id = COSIMfolder[i].index('_L_')
+                Magnet_Name = COSIMfolder[i][:id]
+                tx_line = 'pushd '+ stub+ " \n"
+                fN.write(tx_line)
+                Cf = COSIMfolder[i][id+3:]
+                tx_line = 'call "'+LEDET_exe+'" '+Cf+'\\LEDET\\LEDET '+  Magnet_Name+' ' + str(self.SimulationNumber[0])+ " \n"
+                fN.write(tx_line)
+                tx_line = 'popd '+ " \n"
+                fN.write(tx_line)
+            else:
+                tx_line = txt_stub + " " + str(COSIMfolder[i]) + "\\STEAMConfig.json" + " \n"
+                fN.write(tx_line)
         fN.close()
 
